===============================
pythonthesorimed
===============================

.. image:: https://travis-ci.org/jgirardet/pythonthesorimed.svg?branch=master
    :target: https://travis-ci.org/jgirardet/pythonthesorimed
.. image:: https://readthedocs.org/projects/pythonthesorimed/badge/?version=latest
   :target: http://pythonthesorimed.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
.. image:: https://coveralls.io/repos/github/jgirardet/pythonthesorimed/badge.svg
   :target: https://coveralls.io/github/jgirardet/pythonthesorimed
.. image:: https://badge.fury.io/py/pythonthesorimed.svg
   :target: https://pypi.python.org/pypi/pythonthesorimed/
   :alt: Pypi package


Interface python pour thesorimed


* License : GNU General Public License v3 
* Documentation: https://pythonthesorimed.readthedocs.org/en/latest/
* Source: https://github.com/jgirardet/pythonthesorimed

Features
--------

* TODO

Usage
-----

* TODO

